﻿using System.Drawing;
using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트
        /// </summary>
        private LightningChartUltimate chart = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            InitializeChart();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 다각형 추가하기 - AddPolygon(chart, title, color, pointArray, allowIntersection)

        /// <summary>
        /// 다각형 추가하기
        /// </summary>
        /// <param name="chart">차트</param>
        /// <param name="title">제목</param>
        /// <param name="color">색상</param>
        /// <param name="pointArray">포인트 배열</param>
        /// <param name="allowIntersection">교차 허용 여부</param>
        private void AddPolygon(LightningChartUltimate chart, string title, Color color, PointDouble2D[] pointArray, bool allowIntersection)
        {
            PolygonSeries series = new PolygonSeries(chart.ViewXY, chart.ViewXY.XAxes[0], chart.ViewXY.YAxes[0]);

            series.Fill.Color           = Color.FromArgb(200, color);
            series.Fill.GradientFill    = GradientFill.Solid;
            series.Title.Visible        = true;
            series.Title.Color          = Color.FromArgb(255, 30, 30, 30);
            series.Title.Text           = title;
            series.Title.Shadow.Style   = TextShadowStyle.DropShadow;
            series.Points               = pointArray;
            series.IntersectionsAllowed = allowIntersection;

            chart.ViewXY.PolygonSeries.Add(series);
        }

        #endregion
        #region 차트 초기화하기 - InitializeChart()

        /// <summary>
        /// 차트 초기화하기
        /// </summary>
        private void InitializeChart()
        {
            this.chart = new LightningChartUltimate();
            
            this.chart.BeginUpdate();
            
            this.chart.Name   = "chart";
            this.chart.Parent = this;
            this.chart.Dock   = DockStyle.Fill;

            this.chart.Title.Font = Font;
            this.chart.Title.Text = "다각형 차트";

            this.chart.RenderOptions.AntiAliasLevel = 4;

            ViewXY viewXY = this.chart.ViewXY;

            AxisX axisX = viewXY.XAxes[0];

            axisX.Title.Font         = Font;
            axisX.Title.Text         = "X축";
            axisX.ValueType          = AxisValueType.Number;
            axisX.ScrollMode         = XAxisScrollMode.None;

            AxisY axisY = viewXY.YAxes[0];

            axisY.Title.Font = Font;
            axisY.Title.Text = "Y축";

            ChartHelper.SetDarkFlatStyle(this.chart);

            Color color1 = Color.FromArgb(255, 192, 0);
            Color color2 = Color.FromArgb(255, 94 , 0);

            AddPolygon
            (
                this.chart,
                "다각형 A",
                ChartTools.CalcGradient(color1, color2, 0),
                new PointDouble2D[]
                {
                    new PointDouble2D(0, 0 ),
                    new PointDouble2D(0, 10),
                    new PointDouble2D(8, 10),
                    new PointDouble2D(8, 8 ),
                    new PointDouble2D(4, 8 ),
                    new PointDouble2D(3, 7 ),
                    new PointDouble2D(3, 0 ),
                },
                false
            );

            AddPolygon
            (
                this.chart,
                "다각형 B",
                ChartTools.CalcGradient(color1, color2, 25),
                new PointDouble2D[]
                {
                    new PointDouble2D(4, 8),
                    new PointDouble2D(8, 8),
                    new PointDouble2D(8, 6),
                    new PointDouble2D(3, 6),
                    new PointDouble2D(3, 7),
                },
                false
            );

            AddPolygon
            (
                this.chart,
                "다각형 C",
                ChartTools.CalcGradient(color1, color2, 50),
                new PointDouble2D[]
                {
                    new PointDouble2D(3, 6),
                    new PointDouble2D(8, 6),
                    new PointDouble2D(8, 2),
                    new PointDouble2D(5, 2),
                    new PointDouble2D(6, 4),
                    new PointDouble2D(3, 4),
                },
                false
            );

            AddPolygon
            (
                this.chart,
                "다각형 D",
                ChartTools.CalcGradient(color1, color2, 75),
                new PointDouble2D[]
                {
                    new PointDouble2D(3, 4),
                    new PointDouble2D(6, 4),
                    new PointDouble2D(5, 2),
                    new PointDouble2D(8, 2),
                    new PointDouble2D(8, 0),
                    new PointDouble2D(3, 0),
                },
                false
            );

            AddPolygon
            (
                this.chart,
                "다각형 E",
                ChartTools.CalcGradient(color1, color2, 100),
                new PointDouble2D[]
                {
                    new PointDouble2D(6  , 12  ),
                    new PointDouble2D(5  ,  9.5),
                    new PointDouble2D(6.5,  5  ),
                    new PointDouble2D(7.5, 11.5),
                    new PointDouble2D(8.5,  9  ),
                    new PointDouble2D(7.5,  5  ),
                },
                true
            );

            viewXY.ZoomToFit();

            LegendBoxXY legendBoxXY = viewXY.LegendBoxes[0];

            legendBoxXY.Position = LegendBoxPositionXY.SegmentBottomRight;

            this.chart.EndUpdate();
        }

        #endregion
    }
}